# Last-Mile Restrictive Path Planning Algorithm

A general demo can be found at [`presentation.ipynb`](https://github.com/wzjoriv/Larp/blob/main/presentation.ipynb).

Other highlited demos:
* [`Lafayette Court House`](https://github.com/wzjoriv/Larp/blob/main/docs/demos/Lafayette%20Court%20House/presentation.ipynb)
* [`Hot Reloading`](https://github.com/wzjoriv/Larp/blob/main/docs/demos/Hot%20Reloading%20in%20Room/presentation.ipynb)
* [`Routes for Austin TX`](https://github.com/wzjoriv/Larp/blob/main/docs/demos/Routes%20for%20Austin%20TX/presentation.ipynb)

To install, execute:
```bash
pip install larp
```

![alt text](https://github.com/wzjoriv/Larp/blob/main/docs/imgs/route_graph.png?raw=true)